VALUE_TYPE_CHOICES = [
    'string',
    'int',
    'dollar',
    'percentage',
    'bool',
]

PERIOD_ITERATION_CHOICES = [
    'year',
    'quarter',
    'month',
    'day'
]

OVER_PERIOD_ITERATION_CHOICES = [
    'year',
    'quarter',
    'month',
]
